import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardTargetModel} from "../../../stores/DashboardTargetStore";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {ParameterField} from "./ParameterField";
import {Parameter} from "../../../stores/Types";
import {LabLayoutParameters} from "./parameters/LabLayoutParameters";

export type DashboardComponentParametersProps = {
    component: DashboardComponentModel
}

export const DashboardComponentParameters: React.FunctionComponent<DashboardComponentParametersProps> = observer(({component}) => {
    const target = component.viewModel.dashboard_target as DashboardTargetModel
    if (!target) {
        return null;
    }

    if (target.dashboard_id == 'lab_status') {
        return <LabLayoutParameters component={component}/>
    }

    return <React.Fragment>
        {Object.values(target.parameters).map((parameterDef: Parameter) => {
            if (target.isScoreCard && parameterDef.single_row_parameter) {
                return undefined;
            }
            return <ParameterField key={parameterDef.id} parameter={parameterDef} component={component}/>
        })}
    </React.Fragment>
});
