import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../../stores/DashboardComponentStore";
import {HintButton, ModelSelect, PaddedPaper} from "@rx-suite/ui";
import {GoalSetter} from "./GoalSetter";
import {HorizontalCheckboxField} from "./HorizontalCheckboxField";
import {t, Trans} from "@lingui/macro";
import {makeStyles} from "@material-ui/core/styles";
import {StrokeCurveSelect} from "./StrokeCurveSelect";
import {AnnotationSetter} from "./AnnotationSetter";
import {DatalabelCheckboxField} from "./DatalabelCheckboxField";
import {Box, Tab, Tabs, Typography} from "@material-ui/core";
import {ColorSetter} from "./ColorSetter";
import {ScoreCardSettings} from "./ScoreCardSettings";
import {CounterDisplayTypeOptions} from './CounterDisplayTypeOptions';

export type DashboardDisplayTypeOptionsProps = {
    component: DashboardComponentModel
}

const useStyles = makeStyles(() => ({
    wrapper: {
        display: 'flex',
        width: '100%'
    }
}));

export const DashboardDisplayTypeOptions: React.FunctionComponent<DashboardDisplayTypeOptionsProps> = observer(({component}) => {
        const classes = useStyles();

        const [tab, setTab] = React.useState('general_options');
        const handleChange = React.useCallback((e, newValue) => {
            setTab(newValue);
        }, []);

        const useScoreCardSettings = ['score_card'].includes(component.viewModel.display_type);
        const useAnnotations = ['line', 'bar', 'scatter'].includes(component.viewModel.display_type);
        const useColors = !!component.availableCategories.length || !!component.availableSeries.length;
        const useGoals = ['gauge', 'counter'].includes(component.viewModel.display_type);
        const isLayout = ['lab_status'].includes(component.viewModel.display_type);

        if (isLayout) {
            return null;
        }

        if (useScoreCardSettings) {
            return <PaddedPaper>
                <Typography variant={'h6'}><Trans>Configure Table Rows</Trans></Typography>
                <ScoreCardSettings component={component}/>
            </PaddedPaper>
        }

        return <>
            <Box marginBottom={1}>
                <PaddedPaper>
                    <Tabs value={tab} onChange={handleChange}>
                        <Tab label={t`Display Options`} value={'general_options'}/>
                        {useAnnotations && <Tab label={t`Annotations`} value={'annotations'}/>}
                        {useGoals && <Tab label={t`Goals`} value={'goals'}/>}
                        {useColors && <Tab label={t`Colors`} value={'colors'}/>}
                    </Tabs>
                </PaddedPaper>
            </Box>

            <PaddedPaper>
                {tab === 'general_options' && <>
                    <div className={classes.wrapper}>
                        <ModelSelect name={"display_type"} options={component.displayTypes}/>
                        <HintButton title={t`Display Type`}>
                            <Trans>The display type lets you choose how the component looks like, such as different
                                varieties of chart</Trans>
                        </HintButton>
                    </div>
                    <CounterDisplayTypeOptions component={component} />
                    {!['line', 'table'].includes(component.viewModel.display_type) && <div>
                        <DatalabelCheckboxField component={component}/></div>}
                    {['line'].includes(component.viewModel.display_type) && <StrokeCurveSelect component={component}/>}
                    {['bar'].includes(component.viewModel.display_type) && <div>
                        <HorizontalCheckboxField component={component}/></div>}
                </>}
                {tab === 'annotations' && <AnnotationSetter component={component}/>}
                {tab === 'goals' && <GoalSetter component={component}/>}
                {tab === 'colors' && <ColorSetter component={component}/>}
            </PaddedPaper>
        </>
    }
);
