import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {Typography} from "@material-ui/core";
import {makeStyles} from "@material-ui/core/styles";

export type DashboardComponentCounterProps = {
    component: DashboardComponentModel
};

const useStyles = makeStyles(() => ({
    wrapper: {
        display: 'flex',
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        width: '100%'
    },
    textHolder: {
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'center',
        alignItems: 'center',
        height: '100%',
        flexGrow: 1
    }
}));

export const DashboardComponentCounter: React.FunctionComponent<DashboardComponentCounterProps> = observer(({component}) => {
    const classes = useStyles();
    let data = component.viewModel.data || {};
    const displayOptions = component.viewModel.display_options || {};
    if (data.series && data.categories) {
        const newData = {} as { [s: string]: number };
        data.categories.forEach((cat: { name: string, id: string }, i: number) => {
            newData[cat.id] = Number(((data.series[0] || {}).data || {})[i]);
        });
        data = newData;
    } else if (data.metrics) {
        data = data.metrics
    }
    const targets = component.targetIds;
    const goals = displayOptions.goals || {} as { [s: string]: string | number };
    let title = component.viewModel.desc || component.viewModel.name;

    if(displayOptions.counter?.title === "name") {
        title = component.viewModel.name;
    }

    if (component.isNew) {
        return <React.Fragment>
            {((displayOptions.title || {}).position !== 'omit') &&
            <Typography variant={"h5"} style={component.typographyTitleStyle}>{title}</Typography>}
            <div className={classes.wrapper}>
                <div className={classes.textHolder}>
                    <Typography variant="h4">A</Typography>
                    <Typography variant="h3">1/2</Typography>
                </div>
            </div>
        </React.Fragment>;
    } else {
        return <React.Fragment>
            {((displayOptions.title || {}).position !== 'omit') &&
            <Typography variant={"h5"} style={component.typographyTitleStyle}>{title}</Typography>}
            <div className={classes.wrapper}>
                {
                    targets.map((target) => {
                        const resolvedTarget = component.getGoalId(target);
                        return <div className={classes.textHolder} key={target}>
                            <Typography variant="h4">{component.targetParameterName(target)}</Typography>
                            <Typography
                                variant="h3">{data[target] || 0}{(goals[resolvedTarget] ? `/${goals[resolvedTarget]}` : '')}</Typography>
                        </div>;
                    })
                }
            </div>
        </React.Fragment>;
    }
});
