import * as React from 'react';
import {observer} from "mobx-react-lite";
import {DashboardComponentModel} from "../../../stores/DashboardComponentStore";
import {RadarChart} from "@rx-suite/ui";
import {useGraphOptions} from "../../../hooks/useGraphOptions";

export type DashboardComponentRadarChartProps = {
    component: DashboardComponentModel
};

export const DashboardComponentRadarChart: React.FunctionComponent<DashboardComponentRadarChartProps> = observer(({component}) => {
    const series = component.viewModel.data.series || [];
    const options = useGraphOptions(component);

    if (component.isNew) {
        const fakeSeries = [{data: [Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10), Math.ceil(Math.random() * 10)]}]
        return <RadarChart series={fakeSeries}
                           key={JSON.stringify(fakeSeries)}
                           options={{
                               ...options,
                               labels: ['A', 'B', 'C', 'D', 'E'],
                               legend: {show: false},
                               colors: ['#DCDCDC', "#C0C0C0", "#808080", "#606060", "#404040"]
                           }}
        />
    } else {
        return <RadarChart series={series}
                           options={{
                               ...options,
                               legend: {show: false}
                           }}
        />;
    }
});
