import {Button, Dialog, DialogActions, DialogContent, DialogTitle} from "@material-ui/core";
import {t, Trans} from "@lingui/macro";
import * as React from "react";
import {observer} from "mobx-react-lite";
import {ModelProvider, SelectField} from "@rx-suite/ui";
import {LabLayoutComponentModel} from "../../stores/LabLayoutComponentStore";
import {useSnackbar} from "notistack";
import {MachineModel, MachineStore} from "../../stores/MachineStore";
import {VisualAlertSettings} from "./VisualAlertSettings";
import {LayoutEditViewRenderer} from "../../stores/object/LayoutEditViewRenderer";

export type AddLayoutMachineModalProps = {
    model: LabLayoutComponentModel;
    open: boolean;
    handleClose: () => void;
    renderer: LayoutEditViewRenderer;
};

export const AddLayoutMachineModal: React.FunctionComponent<AddLayoutMachineModalProps> = observer(({
                                                                                                        model,
                                                                                                        open,
                                                                                                        handleClose,
                                                                                                        renderer
                                                                                                    }) => {
    const {enqueueSnackbar} = useSnackbar();

    const handleSubmit = React.useCallback(() => {
        enqueueSnackbar(`${t`Machine Added`}`, {variant: "success"});
        renderer.layout.viewModel.components.push(model);
        renderer.setSelectedComponent(model);
        handleClose();
    }, [renderer, model, enqueueSnackbar, handleClose]);

    const handleMachineSelect = React.useCallback((n: string | undefined, machine: MachineModel) => {
        model.viewModel.name = machine.extendedName;
        model.viewModel.machine_sn = machine.sn
    }, [model]);

    const machineSelectOptions = React.useMemo(() => {
        return MachineStore.models.map(m => {
            return {label: m.extendedName, value: m}
        })
    }, [MachineStore.models]);

    return <Dialog open={open} onClose={handleClose} maxWidth={'lg'} fullWidth>
        <ModelProvider value={model}>
            <DialogTitle>{t`Add Machine`}</DialogTitle>
            <DialogContent>
                <SelectField
                    name={'machine_sn'}
                    label={t`Select machine...`}
                    options={machineSelectOptions}
                    value={model.viewModel[name]}
                    error={!!model.errors[name]}
                    helperText={model.errors[name]}
                    onChange={handleMachineSelect}
                />
                <VisualAlertSettings model={model}/>
                <DialogActions>
                    <Button onClick={handleClose} color={"secondary"}><Trans>Close</Trans></Button>
                    <Button onClick={handleSubmit} color={"secondary"}
                            disabled={!model.viewModel.machine_sn || !model.viewModel.name}><Trans>Submit</Trans></Button>
                </DialogActions>
            </DialogContent>
        </ModelProvider>
    </Dialog>
});